@@ -125,7 +125,7 @@ class Wsdl(WsdlBase):
             'native_error': (VariableError, DataVarsError,
                              InstallError, UpdateError, GitError),
             # значения по умолчанию для переменных этого метода
-            'setvars': {'cl_action!': 'update_profile'},
+            'setvars': {'cl_action!': 'update_profile', 'cl_update_world_default': 'rebuild'},
             # описание груп (список лямбда функций)
             'groups': [
                 lambda group: group(_("Repository"),
